# -*-makefile-*-
#
# Copyright (C) 2007 by Sascha Hauer
#               2008, 2009 by Marc Kleine-Budde
#
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

#
# We provide this package
#
PACKAGES-$(PTXCONF_BAREBOX_EMMC) += barebox_emmc

#
# Paths and names
#
BAREBOX_EMMC_VERSION	:= $(call remove_quotes,$(PTXCONF_BAREBOX_EMMC_VERSION))
BAREBOX_EMMC_MD5	:= $(call remove_quotes,$(PTXCONF_BAREBOX_EMMC_MD5))
BAREBOX_EMMC		:= barebox-$(BAREBOX_EMMC_VERSION)
BAREBOX_EMMC_SUFFIX	:= tar.bz2
BAREBOX_EMMC_URL	:= http://www.barebox.org/download/$(BAREBOX_EMMC).$(BAREBOX_EMMC_SUFFIX)
BAREBOX_EMMC_SOURCE	:= $(SRCDIR)/$(BAREBOX_EMMC).$(BAREBOX_EMMC_SUFFIX)
BAREBOX_EMMC_DIR	:= $(BUILDDIR)/$(BAREBOX_EMMC)_emmc
BAREBOX_EMMC_LICENSE	:= GPLv2

BAREBOX_EMMC_CONFIG	:= $(call remove_quotes, $(PTXDIST_PLATFORMCONFIGDIR)/$(PTXCONF_BAREBOX_EMMC_CONFIG))

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------

BAREBOX_EMMC_PATH	:= PATH=$(CROSS_PATH)
BAREBOX_EMMC_ENV 	:= KCONFIG_NOTIMESTAMP=1
BAREBOX_EMMC_MAKEVARS := \
	HOSTCC=$(HOSTCC) \
	ARCH=$(PTXCONF_BAREBOX_EMMC_ARCH_STRING) \
	CROSS_COMPILE=$(BOOTLOADER_CROSS_COMPILE) \
	$(PARALLELMFLAGS)

BAREBOX_EMMC_TAGS_OPT := TAGS cscope

ifdef PTXCONF_BAREBOX_EMMC_BTCS
BAREBOX_EMMC_MAKEVARS += \
	CFLAGS_btcs.o+=-I"$(KERNEL_HEADERS_INCLUDE_DIR)"
endif

ifdef PTXCONF_BAREBOX_EMMC
$(BAREBOX_EMMC_CONFIG):
	@echo
	@echo "****************************************************************************"
	@echo "**** Please generate a barebox config with 'ptxdist menuconfig barebox' ****"
	@echo "**** copy resulting config file to $(BAREBOX_EMMC_CONFIG)               ****"
	@echo "****************************************************************************"
	@echo
	@echo
	@exit 1
endif

ifdef PTXCONF_BAREBOX__EMMC_EXTRA_ENV_PATH
$(STATEDIR)/barebox_emmc.prepare: $(call remove_quotes,$(PTXCONF_BAREBOX_EMMC_EXTRA_ENV_PATH))
$(STATEDIR)/barebox_emmc.prepare: $(shell find $(call remove_quotes,$(PTXCONF_BAREBOX_EMMC_EXTRA_ENV_PATH)) -print 2>/dev/null)
endif

$(STATEDIR)/barebox_emmc.prepare: $(BAREBOX_EMMC_CONFIG) $(STATEDIR)/barebox.compile
	@$(call targetinfo)

	@echo "Using barebox config file: $(<)"
	@install -m 644 "$(<)" "$(BAREBOX_EMMC_DIR)/.config"

	@$(call ptx/oldconfig, BAREBOX_EMMC)
	@diff -q -I "# [^C]" "$(BAREBOX_EMMC_DIR)/.config" "$(<)" > /dev/null || cp "$(BAREBOX_EMMC_DIR)/.config" "$(<)"

ifdef PTXCONF_BAREBOX_EMMC_EXTRA_ENV
	@rm -rf $(BAREBOX_EMMC_DIR)/.ptxdist-defaultenv
	@ptxd_source_kconfig "${PTXDIST_PTXCONFIG}" && \
	ptxd_source_kconfig "${PTXDIST_PLATFORMCONFIG}" && \
	$(foreach path, $(call remove_quotes,$(PTXCONF_BAREBOX_EMMC_EXTRA_ENV_PATH)), \
		if [ -d "$(path)" ]; then \
			ptxd_filter_dir "$(path)" \
			$(BAREBOX_EMMC_DIR)/.ptxdist-defaultenv; \
		else \
			cp "$(path)" $(BAREBOX_EMMC_DIR)/.ptxdist-defaultenv/; \
		fi;)
	@sed -i -e "s,^\(CONFIG_DEFAULT_ENVIRONMENT_PATH=.*\)\"$$,\1 .ptxdist-defaultenv\"," \
		$(BAREBOX_EMMC_DIR)/.config
endif

	@$(call touch)

# ----------------------------------------------------------------------------
# Compile
# ----------------------------------------------------------------------------

$(STATEDIR)/barebox_emmc.compile:
	@$(call targetinfo)
	cd $(BAREBOX_EMMC_DIR) && $(BAREBOX_EMMC_PATH) $(MAKE) $(BAREBOX_EMMC_MAKEVARS)
	@$(call touch)

# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------

$(STATEDIR)/barebox_emmc.install:
	@$(call targetinfo)
# this would be the right way but we need then a working hd_emmc.img creation
	@install -D -m755 $(BAREBOX_EMMC_DIR)/scripts/bareboxenv $(PTXCONF_SYSROOT_HOST)/bin/bareboxenv_emmc
#	@install -D -m755 $(BAREBOX_EMMC_DIR)/scripts/bareboxenv $(PTXCONF_SYSROOT_HOST)/bin/bareboxenv
	@$(call touch)

# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

$(STATEDIR)/barebox_emmc.targetinstall:
	@$(call targetinfo)

#ifdef PTXCONF_BAREBOX_BAREBOXENV
#	@$(call install_init, barebox_emmc)
#	@$(call install_fixup, barebox_emmc,PRIORITY,optional)
#	@$(call install_fixup, barebox_emmc,SECTION,base)
#	@$(call install_fixup, barebox_emmc,AUTHOR,"Robert Schwebel <r.schwebel@pengutronix.de>")
#	@$(call install_fixup, barebox_emmc,DESCRIPTION,missing)

#	@$(call install_copy, barebox_emmc, 0, 0, 0755, $(BAREBOX_EMMC_DIR)/scripts/bareboxenv-target, \
#		/usr/bin/bareboxenv)

#	@$(call install_finish, barebox_emmc)
#endif
# this would be the right way but we need then a working hd_emmc.img creation
	@install -D -m644 $(BAREBOX_EMMC_DIR)/barebox.bin $(IMAGEDIR)/barebox_emmc-image
	@install -D -m644 $(BAREBOX_EMMC_DIR)/barebox_default_env $(IMAGEDIR)/barebox_emmc-default-environment
#	@install -D -m644 $(BAREBOX_EMMC_DIR)/barebox.bin $(IMAGEDIR)/barebox-image
#	@install -D -m644 $(BAREBOX_EMMC_DIR)/barebox_default_env $(IMAGEDIR)/barebox-default-environment
	@$(call touch)

# ----------------------------------------------------------------------------
# Clean
# ----------------------------------------------------------------------------

$(STATEDIR)/barebox_emmc.clean:
	@$(call targetinfo)
	@$(call clean_pkg, BAREBOX_EMMC)
	rm -rf $(IMAGEDIR)/barebox_emmc-image

# ----------------------------------------------------------------------------
# oldconfig / menuconfig
# ----------------------------------------------------------------------------

barebox_emmc_oldconfig barebox_emmc_menuconfig: $(STATEDIR)/barebox_emmc.extract
	@if test -e $(BAREBOX_EMMC_CONFIG); then \
		cp $(BAREBOX_EMMC_CONFIG) $(BAREBOX_EMMC_DIR)/.config; \
	fi
	cd $(BAREBOX_EMMC_DIR) && \
		$(BAREBOX_EMMC_PATH) $(BAREBOX_EMMC_ENV) $(MAKE) $(BAREBOX_EMMC_MAKEVARS) $(subst barebox_emmc_,,$@)
	@if cmp -s $(BAREBOX_EMMC_DIR)/.config $(BAREBOX_EMMC_CONFIG); then \
		echo "barebox_emmc configuration unchanged"; \
	else \
		cp $(BAREBOX_EMMC_DIR)/.config $(BAREBOX_EMMC_CONFIG); \
	fi

# vim: syntax=make
